[Japanese（日本語）](./README.jp.md)
# Auraboros
A game framework of pygame.
This project is made for me, reducing the burden of game dev using pygame.

# how to install
```
pip install auraboros
```

# how to use CLI
```
python -m auraboros 
```

